jacinle.utils.init
==================

.. automodule:: jacinle.utils.init

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      enable_ipdb
      init_main
      release_syslim
      tune_opencv
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: enable_ipdb

.. autofunction:: init_main

.. autofunction:: release_syslim

.. autofunction:: tune_opencv


